@@ -25,10 +25,12 @@ from bakthat.utils import _interval_string_to_seconds
 from bakthat.models import Backups
 from bakthat.sync import BakSyncer, bakmanager_hook, bakmanager_periodic_backups
 
-__version__ = "0.5.3"
+__version__ = "0.5.4"
 
 app = aaargh.App(description="Compress, encrypt and upload files directly to Amazon S3/Glacier/Swift.")
 
+log = logging.getLogger(__name__)
+
 
 class BakthatFilter(logging.Filter):
     def filter(self, rec):
@@ -37,15 +39,6 @@ class BakthatFilter(logging.Filter):
         else:
             return rec.levelno >= logging.WARNING
 
-log = logging.getLogger()
-
-if not log.handlers:
-#    logging.basicConfig(level=logging.INFO, format='%(message)s')
-    handler = logging.StreamHandler()
-    handler.addFilter(BakthatFilter())
-    handler.setFormatter(logging.Formatter('%(message)s'))
-    log.addHandler(handler)
-    log.setLevel(logging.INFO)
 
 STORAGE_BACKEND = dict(s3=S3Backend, glacier=GlacierBackend, swift=SwiftBackend)
 
@@ -147,23 +140,29 @@ def rotate_backups(filename, destination=None, profile="default", config=CONFIG_
     backups = Backups.search(filename, destination, profile=profile, config=config)
     backups_date = [datetime.fromtimestamp(float(backup.backup_date)) for backup in backups]
 
-    to_delete = grandfatherson.to_delete(backups_date,
-                                         days=int(rotate.conf["days"]),
-                                         weeks=int(rotate.conf["weeks"]),
-                                         months=int(rotate.conf["months"]),
-                                         firstweekday=int(rotate.conf["first_week_day"]),
-                                         now=datetime.utcnow())
+    rotate_kwargs = rotate.conf.copy()
+    del rotate_kwargs["first_week_day"]
+    for k, v in rotate_kwargs.iteritems():
+        rotate_kwargs[k] = int(v)
+    rotate_kwargs["firstweekday"] = int(rotate.conf["first_week_day"])
+    rotate_kwargs["now"] = datetime.utcnow()
+
+    to_delete = grandfatherson.to_delete(backups_date, **rotate_kwargs)
     for delete_date in to_delete:
-        backup_date = int(delete_date.strftime("%s"))
-        backup = Backups.search(filename, destination, backup_date=backup_date, profile=profile, config=config).get()
+        try:
+            backup_date = int(delete_date.strftime("%s"))
+            backup = Backups.search(filename, destination, backup_date=backup_date, profile=profile, config=config).get()
 
-        if backup:
-            real_key = backup.stored_filename
-            log.info("Deleting {0}".format(real_key))
+            if backup:
+                real_key = backup.stored_filename
+                log.info("Deleting {0}".format(real_key))
 
-            storage_backend.delete(real_key)
-            backup.set_deleted()
-            deleted.append(real_key)
+                storage_backend.delete(real_key)
+                backup.set_deleted()
+                deleted.append(real_key)
+        except Exception, exc:
+            log.error("Error when deleting {0}".format(backup))
+            log.exception(exc)
 
     BakSyncer(conf).sync_auto()
 
@@ -578,6 +577,15 @@ def reset_sync(**kwargs):
 
 
 def main():
+
+    if not log.handlers:
+    #    logging.basicConfig(level=logging.INFO, format='%(message)s')
+        handler = logging.StreamHandler()
+        handler.addFilter(BakthatFilter())
+        handler.setFormatter(logging.Formatter('%(message)s'))
+        log.addHandler(handler)
+        log.setLevel(logging.INFO)
+
     app.run()
 
 
